@@ -42,6 +42,7 @@
 #include <glibtop/procargs.h>
 #include <glibtop/procmap.h>
 #include <glibtop/procopenfiles.h>
+#include <glibtop/procwd.h>
 
 #include <glibtop/mountlist.h>
 #include <glibtop/fsusage.h>
@@ -80,6 +81,7 @@ union _glibtop_union
 	glibtop_netload		netload;
 	glibtop_ppp		ppp;
 	glibtop_proc_open_files proc_open_files;
+	glibtop_proc_wd		proc_wd;
 };
 
 G_END_DECLS
